@@ -8,7 +8,20 @@ itertools and builtins for AsyncIO and mixed iterables
 __author__ = "John Reese"
 from . import asyncio
 from .__version__ import __version__
-from .builtins import enumerate, iter, list, map, max, min, next, set, sum, zip
+from .builtins import (
+    all,
+    any,
+    enumerate,
+    iter,
+    list,
+    map,
+    max,
+    min,
+    next,
+    set,
+    sum,
+    zip,
+)
 from .itertools import (
     accumulate,
     chain,
