@@ -13,6 +13,7 @@ use with `await`, `async for`, etc.
 
 import asyncio
 import builtins
+from enum import Enum
 from typing import (
     Any,
     AsyncIterable,
@@ -28,8 +29,59 @@ from typing import (
     overload,
 )
 
+from . import asyncio as ait_asyncio
 from .helpers import Orderable, maybe_await
-from .types import T1, T2, T3, T4, T5, AnyIterable, AnyIterator, AnyStop, R, T
+from .types import (
+    T1,
+    T2,
+    T3,
+    T4,
+    T5,
+    AnyIterable,
+    AnyIterator,
+    AnyStop,
+    R,
+    T,
+    MaybeAwaitable,
+)
+
+
+class Sentinel(Enum):
+    """
+    :meta private:
+    """
+
+    MISSING = object()
+
+
+async def all(itr: AnyIterable[MaybeAwaitable[Any]]) -> bool:
+    """
+    Return True if all values are truthy in a mixed iterable, else False.
+    The iterable will be fully consumed and any awaitables will
+    automatically be awaited.
+
+    Example::
+
+        if await all(it):
+            ...
+
+    """
+    return builtins.all(await ait_asyncio.gather_iter(itr))
+
+
+async def any(itr: AnyIterable[MaybeAwaitable[Any]]) -> bool:
+    """
+    Return True if any value is truthy in a mixed iterable, else False.
+    The iterable will be fully consumed and any awaitables will
+    automatically be awaited.
+
+    Example::
+
+        if await any(it):
+            ...
+
+    """
+    return builtins.any(await ait_asyncio.gather_iter(itr))
 
 
 def iter(itr: AnyIterable[T]) -> AsyncIterator[T]:
@@ -41,9 +93,9 @@ def iter(itr: AnyIterable[T]) -> AsyncIterator[T]:
     Standard iterables will be wrapped in an async generator yielding
     each item in the iterable in the same order.
 
-    Examples:
+    Examples::
 
-        async for iter(range(10)):
+        async for value in iter(range(10)):
             ...
 
     """
@@ -60,32 +112,49 @@ def iter(itr: AnyIterable[T]) -> AsyncIterator[T]:
     return gen()
 
 
+@overload
 async def next(itr: AnyIterator[T]) -> T:
+    ...
+
+
+@overload
+async def next(itr: AnyIterator[T1], default: T2) -> Union[T1, T2]:
+    ...
+
+
+async def next(
+    itr: AnyIterator[T1], default: Union[T2, Sentinel] = Sentinel.MISSING
+) -> Union[T1, T2]:
     """
     Return the next item of any mixed iterator.
 
     Calls builtins.next() on standard iterators, and awaits itr.__anext__()
     on async iterators.
 
-    Example:
+    Example::
 
         value = await next(it)
 
     """
-    if isinstance(itr, AsyncIterator):
-        return await itr.__anext__()
-
     try:
-        return builtins.next(itr)
-    except StopIteration:
-        raise StopAsyncIteration
+        if isinstance(itr, AsyncIterator):
+            return await itr.__anext__()
+
+        try:
+            return builtins.next(itr)
+        except StopIteration:
+            raise StopAsyncIteration
+    except StopAsyncIteration:
+        if default is Sentinel.MISSING:
+            raise
+        return default
 
 
 async def list(itr: AnyIterable[T]) -> List[T]:
     """
     Consume a mixed iterable and return a list of items in order.
 
-    Example:
+    Example::
 
         await list(range(5))
         -> [0, 1, 2, 3, 4]
@@ -98,7 +167,7 @@ async def set(itr: AnyIterable[T]) -> Set[T]:
     """
     Consume a mixed iterable and return a set of items.
 
-    Example:
+    Example::
 
         await set([0, 1, 2, 3, 0, 1, 2, 3])
         -> {0, 1, 2, 3}
@@ -113,7 +182,7 @@ async def enumerate(
     """
     Consume a mixed iterable and yield the current index and item.
 
-    Example:
+    Example::
 
         async for index, value in enumerate(...):
             ...
@@ -129,7 +198,7 @@ async def map(fn: Callable[[T], R], itr: AnyIterable[T]) -> AsyncIterator[R]:
     """
     Modify item of a mixed iterable using the given function or coroutine.
 
-    Example:
+    Example::
 
         async for response in map(func, data):
             ...
@@ -142,14 +211,14 @@ async def map(fn: Callable[[T], R], itr: AnyIterable[T]) -> AsyncIterator[R]:
 
 @overload
 async def max(
-    itr: AnyIterable[Orderable], *, key: Optional[Callable] = None,
+    itr: AnyIterable[Orderable], *, key: Optional[Callable] = None
 ) -> Orderable:  # pragma: no cover
     pass
 
 
 @overload
 async def max(
-    itr: AnyIterable[Orderable], *, default: T, key: Optional[Callable] = None,
+    itr: AnyIterable[Orderable], *, default: T, key: Optional[Callable] = None
 ) -> Union[Orderable, T]:  # pragma: no cover
     pass
 
@@ -158,7 +227,7 @@ async def max(itr: AnyIterable[Orderable], **kwargs: Any) -> Any:
     """
     Return the largest item in an iterable or the largest of two or more arguments.
 
-    Example:
+    Example::
 
         await min(range(5))
         -> 4
@@ -201,14 +270,14 @@ async def max(itr: AnyIterable[Orderable], **kwargs: Any) -> Any:
 
 @overload
 async def min(
-    itr: AnyIterable[Orderable], *, key: Optional[Callable] = None,
+    itr: AnyIterable[Orderable], *, key: Optional[Callable] = None
 ) -> Orderable:  # pragma: no cover
     pass
 
 
 @overload
 async def min(
-    itr: AnyIterable[Orderable], *, default: T, key: Optional[Callable] = None,
+    itr: AnyIterable[Orderable], *, default: T, key: Optional[Callable] = None
 ) -> Union[Orderable, T]:  # pragma: no cover
     pass
 
@@ -217,7 +286,7 @@ async def min(itr: AnyIterable[Orderable], **kwargs: Any) -> Any:
     """
     Return the smallest item in an iterable or the smallest of two or more arguments.
 
-    Example:
+    Example::
 
         await min(range(5))
         -> 0
@@ -262,7 +331,7 @@ async def sum(itr: AnyIterable[T], start: T = None) -> T:
     """
     Compute the sum of a mixed iterable, adding each value with the start value.
 
-    Example:
+    Example::
 
         await sum(generator())
         -> 1024
@@ -280,7 +349,6 @@ async def sum(itr: AnyIterable[T], start: T = None) -> T:
     return value
 
 
-# pylint: disable=undefined-variable,multiple-statements,too-many-arguments
 @overload
 def zip(__iter1: AnyIterable[T1]) -> AsyncIterator[Tuple[T1]]:  # pragma: no cover
     pass
@@ -334,12 +402,11 @@ def zip(
     pass
 
 
-# pylint: enable=undefined-variable,multiple-statements,too-many-arguments
 async def zip(*itrs: AnyIterable[Any]) -> AsyncIterator[Tuple[Any, ...]]:
     """
     Yield a tuple of items from mixed iterables until the shortest is consumed.
 
-    Example:
+    Example::
 
         async for a, b, c in zip(i, j, k):
             ...
