@@ -43,7 +43,7 @@ async def accumulate(
 
     Accepts both a standard function or a coroutine for accumulation.
 
-    Example:
+    Example::
 
         data = [1, 2, 3, 4]
 
@@ -73,7 +73,7 @@ class Chain:
 
         Consumes the first iterable lazily, in entirety, then the second, and so on.
 
-        Example:
+        Example::
 
             async for value in chain([1, 2, 3], [7, 8, 9]):
                 ...  # 1, 2, 3, 7, 8, 9
@@ -102,7 +102,7 @@ async def combinations(itr: AnyIterable[T], r: int) -> AsyncIterator[Tuple[T, ..
     Simple wrapper around itertools.combinations for asyncio.
     This will consume the entire iterable before yielding values.
 
-    Example:
+    Example::
 
         async for value in combinations(range(4), 3):
             ...  # (0, 1, 2), (0, 1, 3), (0, 2, 3), (1, 2, 3)
@@ -122,7 +122,7 @@ async def combinations_with_replacement(
     Simple wrapper around itertools.combinations_with_replacement.
     This will consume the entire iterable before yielding values.
 
-    Example:
+    Example::
 
         async for value in combinations_with_replacement("ABC", 2):
             ...  # ("A", "A"), ("A", "B"), ("A", "C"), ("B", "B"), ...
@@ -141,7 +141,7 @@ async def compress(
 
     Stops when either the iterable or the selectors have been exhausted.
 
-    Example:
+    Example::
 
         async for value in compress(range(5), [1, 0, 0, 1, 1]):
             ...  # 0, 3, 4
@@ -155,7 +155,7 @@ async def count(start: N = 0, step: N = 1) -> AsyncIterator[N]:
     """
     Yield an infinite series, starting at the given value and increasing by step.
 
-    Example:
+    Example::
 
         async for value in counter(10, -1):
             ...  # 10, 9, 8, 7, ...
@@ -175,7 +175,7 @@ async def cycle(itr: AnyIterable[T]) -> AsyncIterator[T]:
     Lazily consumes the iterable when the next value is needed, and caching
     the values in memory for future iterations of the series.
 
-    Example:
+    Example::
 
         async for value in cycle([1, 2]):
             ...  # 1, 2, 1, 2, 1, 2, ...
@@ -199,7 +199,7 @@ async def dropwhile(
 
     Accepts both standard functions and coroutines for the predicate.
 
-    Example:
+    Example::
 
         def pred(x):
             return x < 4
@@ -225,7 +225,7 @@ async def filterfalse(
 
     Accepts both standard functions and coroutines for the predicate.
 
-    Example:
+    Example::
 
         def pred(x):
             return x < 4
@@ -239,7 +239,6 @@ async def filterfalse(
             yield item
 
 
-# pylint: disable=undefined-variable,multiple-statements
 @overload
 def groupby(itr: AnyIterable[T]) -> AsyncIterator[Tuple[T, List[T]]]:  # pragma: nocover
     pass
@@ -252,7 +251,6 @@ def groupby(
     pass
 
 
-# pylint: enable=undefined-variable,multiple-statements
 async def groupby(
     itr: AnyIterable[T], key: Optional[KeyFunction[T, R]] = None
 ) -> AsyncIterator[Tuple[Any, List[T]]]:
@@ -264,7 +262,7 @@ async def groupby(
     coroutines for the key function.  Suggest sorting by the key
     function before using groupby.
 
-    Example:
+    Example::
 
         data = ["A", "a", "b", "c", "C", "c"]
 
@@ -274,12 +272,15 @@ async def groupby(
 
     """
     if key is None:
-        key = lambda x: x
+        key = lambda x: x  # noqa: E731
 
     grouping: List[T] = []
 
     it = iter(itr)
-    item = await next(it)
+    try:
+        item = await next(it)
+    except StopAsyncIteration:
+        return
     grouping = [item]
 
     j = await maybe_await(key(item))
@@ -295,7 +296,6 @@ async def groupby(
     yield j, grouping
 
 
-# pylint: disable=undefined-variable,multiple-statements
 @overload
 def islice(
     itr: AnyIterable[T], __stop: Optional[int]
@@ -310,7 +310,6 @@ def islice(
     pass
 
 
-# pylint: enable=undefined-variable,multiple-statements
 async def islice(itr: AnyIterable[T], *args: Optional[int]) -> AsyncIterator[T]:
     """
     Yield selected items from the given iterable.
@@ -321,7 +320,7 @@ async def islice(itr: AnyIterable[T], *args: Optional[int]) -> AsyncIterator[T]:
     Starting from the start index (or zero), stopping at the stop
     index (or until exhausted), skipping items if step > 0.
 
-    Example:
+    Example::
 
         data = range(10)
 
@@ -369,7 +368,7 @@ async def permutations(
     Simple wrapper around itertools.combinations for asyncio.
     This will consume the entire iterable before yielding values.
 
-    Example:
+    Example::
 
         async for value in permutations(range(3)):
             ...  # (0, 1, 2), (0, 2, 1), (1, 0, 2), ...
@@ -381,7 +380,7 @@ async def permutations(
 
 
 async def product(
-    *itrs: AnyIterable[T], repeat: int = 1  # pylint: disable=redefined-outer-name
+    *itrs: AnyIterable[T], repeat: int = 1
 ) -> AsyncIterator[Tuple[T, ...]]:
     """
     Yield cartesian products of all iterables.
@@ -389,7 +388,7 @@ async def product(
     Simple wrapper around itertools.combinations for asyncio.
     This will consume all iterables before yielding any values.
 
-    Example:
+    Example::
 
         async for value in product("abc", "xy"):
             ...  # ("a", "x"), ("a", "y"), ("b", "x"), ...
@@ -407,7 +406,7 @@ async def repeat(elem: T, n: int = -1) -> AsyncIterator[T]:
     """
     Yield the given value repeatedly, forever or up to n times.
 
-    Example:
+    Example::
 
         async for value in repeat(7):
             ...  # 7, 7, 7, 7, 7, 7, ...
@@ -429,7 +428,7 @@ async def starmap(
     Each iterable contained within will be unpacked and consumed before
     executing the function or coroutine.
 
-    Example:
+    Example::
 
         data = [(1, 1), (1, 1, 1), (2, 2)]
 
@@ -450,7 +449,7 @@ async def takewhile(
 
     Accepts both standard functions and coroutines for the predicate.
 
-    Example:
+    Example::
 
         def pred(x):
             return x < 4
@@ -480,7 +479,7 @@ def tee(itr: AnyIterable[T], n: int = 2) -> Tuple[AsyncIterator[T], ...]:
     used in keeping values in the queues until the other iterators finish
     consuming them.
 
-    Example:
+    Example::
 
         it1, it2 = tee(range(5), n=2)
 
@@ -497,15 +496,23 @@ def tee(itr: AnyIterable[T], n: int = 2) -> Tuple[AsyncIterator[T], ...]:
 
     async def gen(k: int, q: asyncio.Queue) -> AsyncIterator[T]:
         if k == 0:
-            async for value in iter(itr):
-                await asyncio.gather(*[queue.put(value) for queue in queues[1:]])
-                yield value
+            try:
+                async for value in iter(itr):
+                    await asyncio.gather(
+                        *[queue.put((None, value)) for queue in queues[1:]]
+                    )
+                    yield value
+            except Exception as e:
+                await asyncio.gather(*[queue.put((e, None)) for queue in queues[1:]])
+                raise
 
-            await asyncio.gather(*[queue.put(sentinel) for queue in queues[1:]])
+            await asyncio.gather(*[queue.put((None, sentinel)) for queue in queues[1:]])
 
         else:
             while True:
-                value = await q.get()
+                error, value = await q.get()
+                if error is not None:
+                    raise error
                 if value is sentinel:
                     break
                 yield value
@@ -522,7 +529,7 @@ async def zip_longest(
     If shorter iterables are exhausted, the default value will be used
     until all iterables are exhausted.
 
-    Example:
+    Example::
 
         a = range(3)
         b = range(5)
