@@ -59,7 +59,7 @@ class AsyncioTest(TestCase):
         fns = [fn(1), asyncio.ensure_future(fn(2))]
         if hasattr(asyncio, "create_task"):
             # 3.7 only
-            fns.append(asyncio.create_task(fn(3)))  # pylint: disable=no-member
+            fns.append(asyncio.create_task(fn(3)))
         else:
             fns.append(fn(3))
 
@@ -74,8 +74,7 @@ class AsyncioTest(TestCase):
         async def fn(arg):
             nonlocal counter, max_counter
             counter += 1
-            if max_counter < counter:
-                max_counter = counter
+            max_counter = max(max_counter, counter)
             await asyncio.sleep(0.001)
             counter -= 1
             return arg
@@ -127,3 +126,34 @@ class AsyncioTest(TestCase):
         )
         self.assertEqual(result[1], 0.001)
         self.assertIsInstance(result[0], MyException)
+
+    @async_test
+    async def test_gather_cancel(self):
+        cancelled = False
+        started = False
+
+        async def _fn():
+            nonlocal started, cancelled
+            try:
+                started = True
+                await asyncio.sleep(10)  # might as well be forever
+            except asyncio.CancelledError:
+                nonlocal cancelled
+                cancelled = True
+                raise
+
+        async def _gather():
+            await aio.gather(_fn())
+
+        if hasattr(asyncio, "create_task"):
+            # 3.7+ only
+            task = asyncio.create_task(_gather())
+        else:
+            task = asyncio.ensure_future(_gather())
+        # to insure the gather actually runs
+        await asyncio.sleep(0)
+        task.cancel()
+        with self.assertRaises(asyncio.CancelledError):
+            await task
+        self.assertTrue(started)
+        self.assertTrue(cancelled)
